@@ -294,6 +294,10 @@ class TestAskbotUpdatedQuestion(Base):
         "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
     expected_packages = set()
     expected_usernames = set(['ralph'])
+    expected_emails = dict(ralph='ralph@fedoraproject.org')
+    expected_avatars = dict(ralph="http://www.gravatar.com/avatar/" + \
+        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
+        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_objects = set([
         'tags/town',
         'threads/2',
